library(raster)
library(sf)
library(dplyr)
library(gratia)
library(ggplot2)

#load rasters

moss_richness <- raster("richness_moss_10x10.tif")

elevation <- raster("REMA_1km_dem.tif")
terrain <- raster("Terrain_roughness.tif")

temp_rasters <- list.files(path = "temperature", pattern = "\\.tif$", full.names = TRUE)
temperature <- stack(temp_rasters)


### Extract variables of interest ###


## distance form nearest bird nesting sites/colonies ##

bird_nests <- read.csv("birds_breeding_nesting_sites.csv", header = TRUE)

# make coordinates numeric and remove NAS
bird_nests$Longitude <- as.numeric(bird_nests$Longitude)
bird_nests$Latitude <- as.numeric(bird_nests$Latitude)
bird_nests <- bird_nests[complete.cases(bird_nests), ]

# subset only bird sites < 60
bird_nests <- subset(bird_nests, Latitude < -60)

# convert to points
points <- SpatialPointsDataFrame(coords = bird_nests[c("Longitude", "Latitude")], data = bird_nests,
                                 proj4string = CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"))

# Reproject the to the Antarctic Polar Stereographic projection
antarctica_proj <- CRS("+proj=stere +lat_0=-90 +lon_0=0 +lat_ts=-71 +a=6378273 +b=6356889.449 +units=m +no_defs")
points <- spTransform(points, CRSobj = antarctica_proj)

# Distance from points to each raster cell
distances <- distanceFromPoints(object = moss_richness, xy = points)
plot(distances)

# "mask" the raster to keep only those cells inside Antarctica
distance_birds <- mask(x = distances, mask = moss_richness)
plot(distance_birds)


## distance nearest geothermal sites ##

geotherm <- read.csv("geothermal_sites.csv", header = TRUE)

# make coordinates numeric
geotherm$Longitude <- as.numeric(geotherm$Longitude)
geotherm$Latitude <- as.numeric(geotherm$Latitude)

# convert to points
g_points <- SpatialPointsDataFrame(coords = geotherm[c("Longitude", "Latitude")], data = geotherm,
                                  proj4string = CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"))

# Reproject the to the Antarctic Polar Stereographic projection
antarctica_proj <- CRS("+proj=stere +lat_0=-90 +lon_0=0 +lat_ts=-71 +a=6378273 +b=6356889.449 +units=m +no_defs")
g_points <- spTransform(g_points, CRSobj = antarctica_proj)

# Distance from points to each raster cell
g_distances <- distanceFromPoints(object = moss_richness, xy = g_points)
plot(g_distances)

# "mask" the raster to keep only those cells inside Antarctica
distance_geotherm <- mask(x = g_distances, mask = moss_richness)
plot(distance_geotherm)


## Temperature ##

# calculate min and max temperature of summer months
min_temp <- stackApply(temperature, c(12,1,2), fun = min)
max_temp <- stackApply(temperature, c(12,1,2), fun = max)

avg_min <- calc(min_temp, fun = mean)
avg_max <- calc(max_temp, fun = mean)

avg_min <- resample(avg_min, moss_richness)
avg_max <- resample(avg_max, moss_richness)

### extract values from rasters ##

coords <- coordinates(moss_richness)
richness_values <- extract(moss_richness, coords)
elevation_values <- extract(elevation, coords)
min <- extract(avg_min, coords)
max <- extract(avg_max, coords)
birds <- extract(distances, coords)
geo <- extract(g_distances, coords)
tri <- extract(terrain, coords)

data_df <- data.frame(
  Lat = coords[, 1],              # X-coordinate
  Long = coords[, 2],              # Y-coordinate
  Richness = richness_values,   
  Elevation = elevation_values,
  min_temp = min/10,
  max_temp = max/10,
  birds = birds/1000,
  geotherm = geo/1000,
  tri = tri
)

# clean data

clean_data <- data_df %>%
  mutate(Richness = ifelse(is.na(Richness), 0, Richness)) %>%
  mutate(Elevation = ifelse(is.na(Elevation), 0, Elevation)) %>%
  filter(!is.na(min_temp)) %>%
  filter(Elevation > 0)

clean_data$Richness <- round(clean_data$Richness, digits = 0)


head(clean_data)


## Run analysis ##

# Check the normality of species richness
hist(log(clean_data$Richness), main = "Species Richness Histogram")
qqnorm(data_df$Richness); qqline(data_df$Richness, col = "red")

ks.test(clean_data$Richness, "pnorm", mean(clean_data$Richness), sd(clean_data$Richness))

## GAMs ##

library(mgcv) # For GAMs

gam_model <- gam(Richness ~ Lat + Elevation + min_temp + max_temp + birds + geotherm + tri, data = clean_data, family = "ziP")

gam_model2 <- gam(Richness ~ s(Lat,Long) + s(Lat) + s(Elevation) + 
                  s(min_temp) + s(max_temp) + s(birds) + s(geotherm) + s(tri),
                  data = clean_data, family = "poisson")

gam_model3 <- gam(Richness ~ s(Lat,Long) +s(Lat) + s(Elevation) + 
                    s(min_temp) + s(max_temp) + s(birds) + s(geotherm) + s(tri),
                      data = clean_data)

gam_model4 <- gam(Richness ~ s(Lat,Long) + s(Lat) + s(Elevation) + 
                  s(min_temp) + s(max_temp) + s(birds) + s(geotherm) + s(tri),
                  data = clean_data, family = "quasipoisson")

gam_model5 <- gam(Richness ~ s(Lat,Long) + s(abs(Lat)) + s(Elevation) + 
                  s(min_temp) + s(max_temp) + s(birds) + s(geotherm) + s(tri),
                  data = clean_data, family = "ziP")

gam_model6 <- gam(Richness ~ s(Lat,Long) + s(abs(Lat)) + Elevation + 
                  s(min_temp) + s(max_temp) + s(birds) + s(geotherm) + s(tri),
                  data = clean_data, family = "ziP")

gam_model7 <- gam(Richness ~ s(Lat,Long) + s(abs(Lat)) + Elevation + 
                  s(min_temp) + s(max_temp) + s(birds) + s(geotherm) + tri,
                  data = clean_data, family = "ziP")

# Display the GAM summary

summary(gam_model)
summary(gam_model2)
summary(gam_model3)
summary(gam_model4)
summary(gam_model5)
summary(gam_model6)
summary(gam_model7)

AIC(gam_model4)
AIC(gam_model2)
AIC(gam_model3)

flextable::as_flextable(gam_model3)

anova(gam_model2, gam_model3, test = "Chisq")

k.check(gam_model3)
gam.check(gam_model3)

plot(ggeffects::ggpredict(gam_model2), facets = TRUE)


## plot ##

gratia::draw(gam_model5)

appraise(gam_model5)

sm <- smooth_estimates(gam_model5)
sm

smooths(gam_model5)

(lat <- sm %>%
        add_confint() %>%
        ggplot(aes(y = est, x = sm$`abs(Lat)`)) +
        geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                    alpha = 0.2, fill = "forestgreen") +
        geom_line(colour = "forestgreen", size = 1.5) +
        ylim(-15,45) +
        theme_classic() +
        theme(aspect.ratio = 0.9))
  

(min.p <- sm %>%
        add_confint() %>%
        ggplot(aes(y = est, x = min_temp)) +
        geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                    alpha = 0.2, fill = "forestgreen") +
        geom_line(colour = "forestgreen", size = 1.5) +
        ylim(-35,25) +
        theme_classic() +
        theme(aspect.ratio = 0.9))

(max.p <- sm %>%
        add_confint() %>%
        ggplot(aes(y = est, x = max_temp)) +
        geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                    alpha = 0.2, fill = "forestgreen") +
        geom_line(colour = "forestgreen", size = 1.5) +
        ylim(-10,15) +
        theme_classic() +
        theme(aspect.ratio = 0.9))

(bird.p <- sm %>%
          add_confint() %>%
          ggplot(aes(y = est, x = birds)) +
          geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                      alpha = 0.2, fill = "forestgreen") +
          geom_line(colour = "forestgreen", size = 1.5) +
          ylim(-25,10) +
          theme_classic() +
          theme(aspect.ratio = 0.7))

(geo.p <- sm %>%
          add_confint() %>%
          ggplot(aes(y = est, x = geotherm)) +
          geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                      alpha = 0.2, fill = "forestgreen") +
          geom_line(colour = "forestgreen", size = 1.5) +
          ylim(-10,10) +
          theme_classic() +
          theme(aspect.ratio = 0.7))

(elev.p <- sm %>%
            add_confint() %>%
            ggplot(aes(y = est, x = Elevation)) +
            geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                        alpha = 0.2, fill = "forestgreen") +
            geom_line(colour = "forestgreen", size = 1.5) +
            ylim(-5,5) +
            theme_classic() +
            theme(aspect.ratio = 0.7))

(tri.p <- sm %>%
          add_confint() %>%
          ggplot(aes(y = est, x = tri)) +
          geom_ribbon(aes(ymin = lower_ci, ymax = upper_ci),
                      alpha = 0.2, fill = "forestgreen") +
          geom_line(colour = "forestgreen", size = 1.5) +
          ylim(-5,5) +
          theme_classic() +
          theme(aspect.ratio = 0.7))

gridExtra::grid.arrange(lat, min.p, max.p)

gridExtra::grid.arrange(lat, min.p, max.p,
                        bird.p, geo.p, elev.p, tri.p,
                        nrow = 2, ncol = 4)
